@@ -23,6 +23,14 @@ set geometrie ""
 set icogeometrie ""
 set infostring ""
 set indxhelp ""
+set messagesfile ""
+set messagefile "" 
+set bitmap ""
+
+proc openfilesel { var  } {
+upvar $var toto
+set toto [ tk_getOpenFile -parent .]
+}
 
 proc insertWithTags {w text args} {
   set start [$w index insert]
@@ -65,10 +73,10 @@ proc whichcolor { which } {
   if {$which == "RESETFG"} {set fgcolor ""}
   if {$which == "RESETBG"} {set bgcolor ""}
   if ($tk_version>4) then {
-    if {$which== "FG" } {set fgcolor [tk_chooseColor -initialcolor $fgcolor -title "Foreground Color"];
+    if {$which== "FG" } {set fgcolor [tk_chooseColor -initialcolor $fgcolor -title "foreground color"];
       puts $fgcolor
     }
-  if {$which == "BG"} {set bgcolor [tk_chooseColor -initialcolor $bgcolor -title "BackGround Color"];
+  if {$which == "BG"} {set bgcolor [tk_chooseColor -initialcolor $bgcolor -title "background color"];
       puts $bgcolor
     }
   } else
@@ -251,11 +259,9 @@ proc mkFileDialog { nom titre args }  {
   wm title .$nom "$titre"
   frame .$nom.frame -borderwidth 10
   frame .$nom.frame2 -borderwidth 10
-  frame .$nom.frame.frame3 -borderwidth 10
   frame .$nom.frame.frame4 -borderwidth 10
   set w .$nom.frame
   set w2 .$nom.frame2
-  set w3 .$nom.frame.frame3
   set w4 .$nom.frame.frame4
   set nbf 0
 
@@ -263,20 +269,19 @@ proc mkFileDialog { nom titre args }  {
   pack $w.msg0 -side top
   foreach i $args {
     set nbf [ expr $nbf +1 ]
-    label $w3.l$nbf -text [lindex $i 0]
-    entry $w4.e$nbf -textvariable [lindex $i 1]
-    button $w4.b$nbf -text "..." -command "eval [set [lindex $i 1] tk_getOpenFile]"
-    pack $w3.l$nbf
-    pack $w4.e$nbf
-    pack $w4.b$nbf  -side right
+    frame $w4.f$nbf 
+    label $w4.f$nbf.l$nbf -text [lindex $i 0]
+    entry $w4.f$nbf.e$nbf -textvariable [lindex $i 1]
+    button $w4.f$nbf.b$nbf -text "..." -command "openfilesel [lindex $i 1]"
+    pack $w4.f$nbf.l$nbf $w4.f$nbf.e$nbf $w4.f$nbf.b$nbf  -side left -expand yes
+    pack $w4.f$nbf -expand yes
   }
   button $w2.ok -text OK -command "destroy .$nom"
   button $w2.cancel -text Cancel -command "destroy .$nom"
-  pack $w -side top
-  pack $w3 -side left
-  pack $w4 -side right
-  pack $w2.ok $w2.cancel -side left -fill x
-  pack $w2  -side bottom
+  pack $w -side top -expand yes
+  pack $w4 -side right -expand yes
+  pack $w2.ok $w2.cancel -side left -fill x -expand yes
+  pack $w2  -side bottom -expand yes
 }
 
 proc mkDialog { nom titre args } {
@@ -331,11 +336,13 @@ proc mkGeometry {} {
 }
 
 proc mkFileOption {} {
-  global geometrie
-  global icogeometrie
-  mkFileDialog geometry {Geometry Options} \
-  {"geometry" geometrie} \
-  {"icon geometry" icogeometrie}
+  global messagesfile
+  global messagefile
+  global bitmap
+  mkFileDialog fileoption {Files Options} \
+  {"messagesfile" messagesfile} \
+  {"messagefile" messagefile} \
+  {"bitmap" bitmap} 
 }
 
 proc whichfont { which } {
@@ -440,6 +447,9 @@ proc Affopts { device } {
   global geometrie
   global icogeometrie
   global infostring
+  global messagesfile 
+  global messagefile  
+  global bitmap 
 
   set linecommand "xlock "
 
@@ -456,6 +466,9 @@ proc Affopts { device } {
   if {$prgname!=""} {append linecommand "-program $prgname "}
   if {$geometrie!=""} {append linecommand "-geometry $geometrie "}
   if {$icogeometrie!=""} {append linecommand "-icongeometry $icogeometrie "}
+  if {$messagesfile!=""} {append linecommand "-messagesfile $messagesfile "}
+  if {$bitmap!=""} {append linecommand "-bitmap $bitmap "}
+  if {$icogeometrie!=""} {append linecommand "-icongeometry $icogeometrie "}
   if {$infostring!=""} {append linecommand "-info $infostring "}
 #check actions
   if { $mono == 1 } {append linecommand "-mono "}
@@ -531,7 +544,7 @@ $OPTIONS add command -label "font for a specific mode" -command "mkFont MFONT"
 
 
 $OPTIONS add command -label "geometry options" -command "mkGeometry"
-$OPTIONS add command -label "File options" -command "mkFileOption"
+$OPTIONS add command -label "file options" -command "mkFileOption"
 $OPTIONS add command -label "message options" -command "mkMessage"
 
 #Color
@@ -539,18 +552,18 @@ menubutton .menu.button4 -text "color" -menu .menu.button4.color
 menu .menu.button4.color
 set COLOR .menu.button4.color
 #if {$tk_version < 4} then {
-#$COLOR add command -label "Foreground options for password" -command "mkColor FG"
-#$COLOR add command -label "Background options for password" -command "mkColor BG"
+#$COLOR add command -label "foreground options for password" -command "mkColor FG"
+#$COLOR add command -label "background options for password" -command "mkColor BG"
 #}
 #else {
-$COLOR add command -label "Foreground options for password" -command "tk_chooseColor"
-$COLOR add command -label "Background options for password" -command "tk_chooseColor"
+$COLOR add command -label "foreground options for password" -command "tk_chooseColor"
+$COLOR add command -label "background options for password" -command "tk_chooseColor"
 #}
 menubutton .menu.button3 -text "help" -menu .menu.button3.help
 menu .menu.button3.help
 set HELP .menu.button3.help
-$HELP add command -label "About xlock" -command "Helpxlock"
-$HELP add command -label "About author" -command "mkAuthor"
+$HELP add command -label "about xlock" -command "Helpxlock"
+$HELP add command -label "about author" -command "mkAuthor"
 
 pack .menu.button  .menu.button2 .menu.button4 -side left
 pack .menu.button3 -side right
@@ -567,8 +580,8 @@ listbox $LISTSCROL.list -yscroll  "$LISTSCROL.scroll set"
 #insert all modes in list
 #---------------------------
 $LISTSCROL.list  insert 0 \
-ant ball bat blot \
-bouboule bounce braid bubble bug \
+ant atlantis ball bat blot \
+bouboule bounce braid bubble bubble3d bug \
 cage cartoon clock coral crystal \
 daisy dclock deco demon dilemma discrete drift \
 eyes fadeplot flag flame flow forest \
