@@ -73,6 +73,7 @@ add("North", Panel3);
 
 add("Center",lst);
 lst.addItem("ant");
+lst.addItem("atlantis");
 lst.addItem("ball");
 lst.addItem("bat");
 lst.addItem("blot");
@@ -80,6 +81,7 @@ lst.addItem("bouboule");
 lst.addItem("bounce");
 lst.addItem("braid");
 lst.addItem("bubble");
+lst.addItem("bubble3d");
 lst.addItem("bug");
 lst.addItem("cage");
 lst.addItem("cartoon");
