@@ -455,6 +455,7 @@ XCOMM -DUSE_BUTTON_LOGOUT=10    Enable logout button and set appear time (min)
 XCOMM -DDEF_BUTTON_LOGOUT=\"5\" Set default logout button (minutes) 
 XCOMM -DUSE_BOMB                Enable automatic logout mode (does not come up
 XCOMM                           in random mode)
+XCOMM -DUSE_UNSTABLE            Enable unstable bubble3d GL mode
 XCOMM -DCLOSEDOWN_LOGOUT        Use with USE_AUTO_LOGOUT, USE_BUTTON_LOGOUT,
 XCOMM                           USE_BOMB if using xdm
 XCOMM -DSESSION_LOGOUT          Alternate of above
@@ -462,7 +463,8 @@ XCOMM -DSTAFF_FILE=\"/etc/xlock.staff\"  File of staff who are exempt
 XCOMM -DSTAFF_NETGROUP=\"/etc/xlock.netgroup\"  Netgroup that is exempt
 
 XCOMM May have to combine in one long line if "+=" does not work
-OPTDEF = -DUSE_VROOT -DALWAYS_ALLOW_ROOT -DUSE_BOMB -DCHECK_OLD_ARGS
+OPTDEF = -DUSE_VROOT -DALWAYS_ALLOW_ROOT -DUSE_BOMB
+XCOMM  OPTDEF += -DUSE_UNSTABLE
 XCOMM  OPTDEF += -DUSE_SYSLOG -DSYSLOG_FACILITY=LOG_AUTH
 XCOMM  OPTDEF += -DSYSLOG_WARNING=LOG_WARNING
 XCOMM  OPTDEF += -DSYSLOG_NOTICE=LOG_NOTICE -DSYSLOG_INFO=LOG_INFO
