@@ -5,7 +5,7 @@
  */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)ant.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)ant.c	4.11 98/06/18 xlockmore";
 
 #endif
 
@@ -63,6 +63,7 @@ static const char sccsid[] = "@(#)ant.c	4.07 97/11/24 xlockmore";
  "*size: -7 \n" \
  "*ncolors: 64 \n" \
  "*neighbors: 0 \n" \
+ "*sharpturn: False \n" \
  "*fullrandom: True \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
@@ -79,24 +80,30 @@ static const char sccsid[] = "@(#)ant.c	4.07 97/11/24 xlockmore";
 extern int  neighbors;
 
 #define DEF_TRUCHET  "False"
+#define DEF_SHARPTURN  "False"
 
 static Bool truchet;
+static Bool sharpturn;
 
 static XrmOptionDescRec opts[] =
 {
 	{"-truchet", ".ant.truchet", XrmoptionNoArg, (caddr_t) "on"},
-	{"+truchet", ".ant.truchet", XrmoptionNoArg, (caddr_t) "off"}
+	{"+truchet", ".ant.truchet", XrmoptionNoArg, (caddr_t) "off"},
+	{"-sharpturn", ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "on"},
+	{"+sharpturn", ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & truchet, "truchet", "Truchet", DEF_TRUCHET, t_Bool}
+	{(caddr_t *) & truchet, "truchet", "Truchet", DEF_TRUCHET, t_Bool},
+   {(caddr_t *) & sharpturn, "sharpturn", "SharpTurn", DEF_SHARPTURN, t_Bool}
 };
 static OptionStruct desc[] =
 {
 #if 0
       {"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
 #endif
-	{"-/+truchet", "turn on/off Truchet lines"}
+	{"-/+truchet", "turn on/off Truchet lines"},
+	{"-/+sharpturn", "turn on/off sharp turns (6 or 12 neighbors only)"}
 };
 
 ModeSpecOpt ant_opts =
@@ -121,8 +128,8 @@ ModStruct   ant_description =
 #define REDRAWSTEP 2000		/* How much tape to draw per cycle */
 #define MINGRIDSIZE 24
 #define MINSIZE 1
+#define MINRANDOMSIZE 5
 #define ANGLES 360
-#define NEIGHBORKINDS 3
 
 typedef struct {
 	unsigned char color;
@@ -148,6 +155,7 @@ typedef struct {
 	int         n;
 	int         redrawing, redrawpos;
 	int         truchet;	/* Only for Turk modes */
+	int         sharpturn;	/* Only for even neighbors > 4 (i.e. 6 and 12) */
 	statestruct machine[NUMSTIPPLES * STATES];
 	unsigned char *tape;
 	unsigned char *truchet_state;
@@ -162,9 +170,14 @@ typedef struct {
 	} shape;
 } antfarmstruct;
 
-static char plots[NEIGHBORKINDS] =
-{3, 4, 6};			/* Neighborhoods, 8 just makes a mess */
+static char plots[] =
+{3,
+#if 1				/* Without this... this mode is misnamed... */
+ 4,
+#endif
+ 6};				/* Neighborhoods, 8 just makes a mess */
 
+#define NEIGHBORKINDS (sizeof plots / sizeof *plots)
 
 /* Relative ant moves */
 #define FS 0			/* Step */
@@ -464,17 +477,9 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 		else
 			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
 			    ap->shape.hexagon, 6, Convex, CoordModePrevious);
-#if 1				/* #ifndef XSCREENSAVER_PREF */
-/*-
- * jwz sez: this looks like crap 
- * dab says this is illogical; only squares (neighbors == 4) were in the
- *   original description of ants, in addition, removing them here is
- *   incorrect.
- */
 	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
 		ap->xb + ap->xs * col, ap->yb + ap->ys * row, ap->xs, ap->ys);
-#endif
 	} else {		/* TRI */
 		int         orient = (col + row) % 2;	/* O left 1 right */
 
@@ -501,26 +506,43 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
 
 	if (ap->neighbors == 6) {
+
 		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
 		int         side;
+		int         fudge = 7; /* fudge because the hexagons are not exact */
 		XPoint      hex, hex2;
 
-		/* Very crude approx of Sqrt 3, so it will not cause drawing errors. */
-		hex.x = ap->xb + ccol * ap->xs - (int) ((double) ap->xs * 1.6 / 2.0);
-		hex.y = ap->yb + crow * ap->ys - (int) ((double) ap->ys * 1.6 / 2.0);
-		for (side = 0; side < 6; side++) {
-			if (side > 0) {
-				hex.x += ap->shape.hexagon[side].x;
-				hex.y += ap->shape.hexagon[side].y;
+		if (ap->sharpturn) {
+			hex.x = ap->xb + ccol * ap->xs - (int) ((double) ap->xs / 2.0) - 1;
+			hex.y = ap->yb + crow * ap->ys - (int) ((double) ap->ys / 2.0) - 1;
+			for (side = 0; side < 6; side++) {
+				if (side > 0) {
+					hex.x += ap->shape.hexagon[side].x;
+					hex.y += ap->shape.hexagon[side].y;
+				}
+				if (truchetstate == side % 2)
+					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+						 hex.x, hex.y, ap->xs, ap->ys,
+						 ((570 - (side * 60) + fudge) % 360) * 64, (120 - 2 * fudge) * 64);
+			}
+		} else {
+			/* Very crude approx of Sqrt 3, so it will not cause drawing errors. */
+			hex.x = ap->xb + ccol * ap->xs - (int) ((double) ap->xs * 1.6 / 2.0);
+			hex.y = ap->yb + crow * ap->ys - (int) ((double) ap->ys * 1.6 / 2.0);
+			for (side = 0; side < 6; side++) {
+				if (side > 0) {
+					hex.x += ap->shape.hexagon[side].x;
+					hex.y += ap->shape.hexagon[side].y;
+				}
+				hex2.x = hex.x + ap->shape.hexagon[side + 1].x / 2;
+				hex2.y = hex.y + ap->shape.hexagon[side + 1].y / 2;
+				if (truchetstate == side % 3)
+					/* Crude approx of 120 deg, so it will not cause drawing errors. */
+					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+						 hex2.x, hex2.y,
+						 (int) ((double) ap->xs * 1.5), (int) ((double) ap->ys * 1.5),
+						 ((555 - (side * 60)) % 360) * 64, 90 * 64);
 			}
-			hex2.x = hex.x + ap->shape.hexagon[side + 1].x / 2;
-			hex2.y = hex.y + ap->shape.hexagon[side + 1].y / 2;
-			if (truchetstate == side % 3)
-				/* Crude approx of 120 deg, so it will not cause drawing errors. */
-				XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-					 hex2.x, hex2.y,
-					 (int) ((double) ap->xs * 1.5), (int) ((double) ap->ys * 1.5),
-				  ((555 - (side * 60)) % 360) * 64, 90 * 64);
 		}
 	} else if (ap->neighbors == 4) {
 		if (truchetstate) {
@@ -528,35 +550,36 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 				 ap->xb + ap->xs * col - ap->xs / 2,
 				 ap->yb + ap->ys * row + ap->ys / 2,
 				 ap->xs, ap->ys,
-				 1 * 64, 88 * 64);
+				 0 * 64, 90 * 64);
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 				 ap->xb + ap->xs * col + ap->xs / 2,
 				 ap->yb + ap->ys * row - ap->ys / 2,
 				 ap->xs, ap->ys,
-				 -91 * 64, -88 * 64);
+				 -90 * 64, -90 * 64);
 		} else {
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 				 ap->xb + ap->xs * col - ap->xs / 2,
 				 ap->yb + ap->ys * row - ap->ys / 2,
 				 ap->xs, ap->ys,
-				 -1 * 64, -88 * 64);
+				 0 * 64, -90 * 64);
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 				 ap->xb + ap->xs * col + ap->xs / 2,
 				 ap->yb + ap->ys * row + ap->ys / 2,
 				 ap->xs, ap->ys,
-				 91 * 64, 88 * 64);
+				 90 * 64, 90 * 64);
 		}
 	} else if (ap->neighbors == 3) {
 		int         orient = (col + row) % 2;	/* O left 1 right */
 		int         side, ang;
+		int         fudge = 7; /* fudge because the triangles are not exact */
 		XPoint      tri;
 
 		tri.x = ap->xb + col * ap->xs;
 		tri.y = ap->yb + row * ap->ys;
 		if (orient) {
-			tri.x += (ap->xs / 2 - 2);
+			tri.x += (ap->xs / 2 - 1);
 		} else {
-			tri.x -= (ap->xs / 2 + 2);
+			tri.x -= (ap->xs / 2 - 1);
 		}
 		for (side = 0; side < 3; side++) {
 			if (side > 0) {
@@ -565,13 +588,13 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 			}
 			if (truchetstate == side % 3) {
 				if (orient)
-					ang = (518 - side * 120) % 360;		/* Right */
+					ang = (510 - side * 120) % 360;		/* Right */
 				else
 					ang = (690 - side * 120) % 360;		/* Left */
 				XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 				  tri.x - ap->xs / 2, tri.y - 3 * ap->ys / 4,
 					 ap->xs, 3 * ap->ys / 2,
-					 ang * 64, 45 * 64);
+					 (ang + fudge) * 64, (60 - 2 * fudge) * 64);
 			}
 		}
 	}
@@ -691,11 +714,11 @@ fromTableDirection(unsigned char dir, int neighbors)
 		case TRS:
 			return (ANGLES / neighbors);
 		case THRS:
-			return (ANGLES / (2 * neighbors));
+			return (ANGLES / 2 - ANGLES / neighbors);
 		case TBS:
 			return (ANGLES / 2);
 		case THLS:
-			return (ANGLES - ANGLES / (2 * neighbors));
+			return (ANGLES / 2 + ANGLES / neighbors);
 		case TLS:
 			return (ANGLES - ANGLES / neighbors);
 		case SF:
@@ -703,11 +726,11 @@ fromTableDirection(unsigned char dir, int neighbors)
 		case STR:
 			return (ANGLES + ANGLES / neighbors);
 		case STHR:
-			return (ANGLES + ANGLES / (2 * neighbors));
+			return (3 * ANGLES / 2 - ANGLES / neighbors);
 		case STB:
 			return (3 * ANGLES / 2);
 		case STHL:
-			return (2 * ANGLES - ANGLES / (2 * neighbors));
+			return (3 * ANGLES / 2 + ANGLES / neighbors);
 		case STL:
 			return (2 * ANGLES - ANGLES / neighbors);
 		default:
@@ -729,11 +752,45 @@ getTable(ModeInfo * mi, int i)
 	total = ap->ncolors * ap->nstates;
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-		     "ants %d, neighbors %d, table number %d, colors %d, states %d\n",
-		      ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
+			       "ants %d, neighbors %d, table number %d, colors %d, states %d\n",
+			  ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
 	for (j = 0; j < total; j++) {
 		ap->machine[j].color = *patptr++;
-		ap->machine[j].direction = fromTableDirection(*patptr++, ap->neighbors);
+		if (ap->sharpturn && ap->neighbors > 4 && !(ap->neighbors % 2)) {
+			int         k = *patptr++;
+
+			switch (k) {
+				case TRS:
+					k = THRS;
+					break;
+				case THRS:
+					k = TRS;
+					break;
+				case THLS:
+					k = TLS;
+					break;
+				case TLS:
+					k = THLS;
+					break;
+				case STR:
+					k = STHR;
+					break;
+				case STHR:
+					k = STR;
+					break;
+				case STHL:
+					k = STL;
+					break;
+				case STL:
+					k = STHL;
+					break;
+				default:
+					break;
+			}
+			ap->machine[j].direction = fromTableDirection(k, ap->neighbors);
+		} else {
+			ap->machine[j].direction = fromTableDirection(*patptr++, ap->neighbors);
+		}
 		ap->machine[j].next = *patptr++;
 	}
 	ap->truchet = False;
@@ -756,22 +813,24 @@ getTurk(ModeInfo * mi, int i)
 	total = ap->ncolors * ap->nstates;
 	for (j = 0; j < total; j++) {
 		ap->machine[j].color = (j + 1) % total;
-		ap->machine[j].direction = (power2 & number) ?
-			fromTableDirection(TRS, ap->neighbors) :
-			fromTableDirection(TLS, ap->neighbors);
+		if (ap->sharpturn && ap->neighbors > 4 && !(ap->neighbors % 2)) {
+			ap->machine[j].direction = (power2 & number) ?
+				fromTableDirection(THRS, ap->neighbors) :
+				fromTableDirection(THLS, ap->neighbors);
+		} else {
+			ap->machine[j].direction = (power2 & number) ?
+				fromTableDirection(TRS, ap->neighbors) :
+				fromTableDirection(TLS, ap->neighbors);
+		}
 		ap->machine[j].next = 0;
 		power2 >>= 1;
 	}
-	if (MI_IS_FULLRANDOM(mi))
-		ap->truchet = (Bool) (LRAND() & 1);
-	else
-		ap->truchet = truchet;
 	ap->truchet = (ap->truchet && ap->xs > 2 && ap->ys > 2 &&
 	   (ap->neighbors == 3 || ap->neighbors == 4 || ap->neighbors == 6));
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-			    "ants %d, neighbors %d, Turk's number %d, colors %d\n",
-			    ap->n, ap->neighbors, number, ap->ncolors);
+		      "ants %d, neighbors %d, Turk's number %d, colors %d\n",
+			       ap->n, ap->neighbors, number, ap->ncolors);
 }
 
 void
@@ -789,13 +848,6 @@ init_ant(ModeInfo * mi)
 			return;
 	}
 	ap = &antfarms[MI_SCREEN(mi)];
-#ifdef XSCREENSAVER_PREF
-/* jwz sez: small sizes look like crap, dab says they don't */
-	if (size < 0)
-		size = NRAND(-size) + 1;
-	if (size < 5)
-		size += 5;
-#endif
 	ap->redrawing = 0;
 	if (MI_NPIXELS(mi) <= 2) {
 		if (ap->stippledGC == None) {
@@ -845,14 +897,17 @@ init_ant(ModeInfo * mi)
 			ap->width = 2;
 		if (ap->height < 4)
 			ap->height = 4;
-		if (size < -MINSIZE)
-			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
-				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-		else if (size < MINSIZE) {
-			if (!size)
-				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
-			else
-				ap->ys = MINSIZE;
+    if (size < -MINSIZE) {
+      ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
+              MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
+			if (ap->ys < MINRANDOMSIZE) 
+         ap->ys = MIN(MINRANDOMSIZE,
+              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+    } else if (size < MINSIZE) {
+      if (!size)
+        ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
+      else
+		  	ap->ys = MINSIZE;
 		} else
 			ap->ys = MIN(size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 					       MINGRIDSIZE));
@@ -871,10 +926,13 @@ init_ant(ModeInfo * mi)
 		ap->shape.hexagon[6].x = 0;
 		ap->shape.hexagon[6].y = 0;
 	} else if (ap->neighbors == 4 && ap->neighbors == 8) {
-		if (size < -MINSIZE)
+		if (size < -MINSIZE) {
 			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-		else if (size < MINSIZE) {
+			if (ap->ys < MINRANDOMSIZE) 
+         ap->ys = MIN(MINRANDOMSIZE,
+              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+		} else if (size < MINSIZE) {
 			if (!size)
 				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
 			else
@@ -894,10 +952,13 @@ init_ant(ModeInfo * mi)
 			ap->width = 2;
 		if (ap->height < 2)
 			ap->height = 2;
-		if (size < -MINSIZE)
+		if (size < -MINSIZE) {
 			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-		else if (size < MINSIZE) {
+			if (ap->ys < MINRANDOMSIZE) 
+         ap->ys = MIN(MINRANDOMSIZE,
+              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+		} else if (size < MINSIZE) {
 			if (!size)
 				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
 			else
@@ -923,9 +984,17 @@ init_ant(ModeInfo * mi)
 		}
 	}
 
+	XSetLineAttributes(display, MI_GC(mi), 1, LineSolid, CapNotLast, JoinMiter);
 	MI_CLEARWINDOW(mi);
 	ap->painted = False;
 
+	if (MI_IS_FULLRANDOM(mi)) {
+		ap->truchet = (Bool) (LRAND() & 1);
+		ap->sharpturn = (Bool) (LRAND() & 1);
+	} else {
+		ap->truchet = truchet;
+		ap->sharpturn = sharpturn;
+	}
 	/* Exclude odd # of neighbors, stepping forward not defined */
 	if (!NRAND(NUMSTIPPLES) && ((ap->neighbors + 1) % 2)) {
 		getTable(mi, (int) (NRAND(NTABLES)));
@@ -989,10 +1058,15 @@ draw_ant(ModeInfo * mi)
 			int         a = 0, b;
 
 			if (ap->neighbors == 6) {
-				a = (old_dir / 60) % 3;
-				b = (anant->direction / 60) % 3;
-				a = (a + b + 1) % 3;
-				drawtruchet(mi, anant->col, anant->row, status->color, a);
+				if (ap->sharpturn) {
+					a = (chg_dir / 120 == 2);
+					drawtruchet(mi, anant->col, anant->row, status->color, a);
+				} else {
+					a = (old_dir / 60) % 3;
+					b = (anant->direction / 60) % 3;
+					a = (a + b + 1) % 3;
+					drawtruchet(mi, anant->col, anant->row, status->color, a);
+				}
 			} else if (ap->neighbors == 4) {
 				a = old_dir / 180;
 				b = anant->direction / 180;
