@@ -425,15 +425,15 @@ init_bounce(ModeInfo * mi)
 		BALLBITS(bounce3_bits, bounce3_width, bounce3_height);
 		BALLBITS(bouncemask_bits, bouncemask_width, bouncemask_height);
 	}
-	bp->width = MI_WIN_WIDTH(mi);
-	bp->height = MI_WIN_HEIGHT(mi);
+	bp->width = MI_WIDTH(mi);
+	bp->height = MI_HEIGHT(mi);
 	if (bp->width < 2)
 		bp->width = 2;
 	if (bp->height < 2)
 		bp->height = 2;
 	bp->restartnum = TIME;
 	bounce_windows(mi, bp);
-	bp->nballs = MI_BATCHCOUNT(mi);
+	bp->nballs = MI_COUNT(mi);
 	if (bp->nballs < -MINBALLS) {
 		/* if bp->nballs is random ... the size can change */
 		if (bp->balls != NULL) {
@@ -540,9 +540,9 @@ release_bounce(ModeInfo * mi)
 void
 refresh_bounce(ModeInfo * mi)
 {
-	/* Do nothing, it will refresh by itself */
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
 
+	MI_CLEARWINDOW(mi);
 	bounce_windows(mi, bp);
 }
 
@@ -554,7 +554,7 @@ bounce_windows(ModeInfo * mi, bouncestruct * bs)
 	int         i;
 	int         n;
 
-	if (!MI_WIN_IS_INROOT(mi)) {
+	if (!MI_IS_INROOT(mi)) {
 		bs->nwindow = 0;
 		return;
 	}
