@@ -614,7 +614,7 @@ mutatebug(bugstruct * info, int neighbors)
 
 static void
 makebacteria(ModeInfo * mi,
-	     int n, int startx, int starty, int width, int height)
+	     int n, int startx, int starty, int width, int height, Bool draw)
 {
 	int         i = 0, j = 0, hcol, hrow, colrow;
 	bugfarmstruct *bp = &bugfarms[MI_SCREEN(mi)];
@@ -631,6 +631,7 @@ makebacteria(ModeInfo * mi,
 		if (!bp->arr[colrow] && !bp->bacteria[colrow]) {
 			i++;
 			bp->bacteria[colrow] = True;
+	    drawabacterium(mi, hcol, hrow, True);
 		}
 	}
 }
@@ -801,10 +802,12 @@ init_bug(ModeInfo * mi)
 			drawabug(mi, hcol, hrow, bp->currbug->info.color);
 		}
 	}
-	makebacteria(mi, bp->nhcols * bp->nhrows / 2, 0, 0, bp->nhcols, bp->nhrows);
+	makebacteria(mi, bp->nhcols * bp->nhrows / 2, 0, 0, bp->nhcols, bp->nhrows,
+     False);
 	if (bp->eden)
 		makebacteria(mi, bp->edenwidth * bp->edenheight / 2,
-			     bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight);
+			     bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight,
+           False);
 	bp->redrawing = 1;
 	bp->redrawpos = 0;
 }
@@ -877,10 +880,10 @@ draw_bug(ModeInfo * mi)
 		bp->currbug = bp->currbug->next;
 	}
 	reattach_buglist(bp);
-	makebacteria(mi, FOODPERCYCLE, 0, 0, bp->nhcols, bp->nhrows);
+	makebacteria(mi, FOODPERCYCLE, 0, 0, bp->nhcols, bp->nhrows, True);
 	if (bp->eden)
 		makebacteria(mi, FOODPERCYCLE,
-			     bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight);
+			     bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight, True);
 	if (!bp->n || bp->generation >= MI_CYCLES(mi))
 		init_bug(mi);
 	bp->generation++;
