@@ -70,7 +70,9 @@ static const char sccsid[] = "@(#)crystal.c	4.07 97/11/24 xlockmore";
  "*count: -500 \n" \
  "*cycles: 200 \n" \
  "*size: -15 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*fullrandom: True \n" \
+ "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -238,6 +240,7 @@ typedef struct {
 } crystalatom;
 
 typedef struct {
+	Bool        painted;
 	int         win_width, win_height, num_atom;
 	int         planegroup, a, b, offset_w, offset_h, nx, ny;
 	float       gamma;
@@ -525,6 +528,7 @@ draw_crystal(ModeInfo * mi)
 	crystalstruct *cryst = &crystals[MI_SCREEN(mi)];
 	int         i;
 
+	cryst->painted = True;
 	XSetFunction(display, cryst->gc, GXxor);
 	for (i = 0; i < cryst->num_atom; i++) {
 		crystalatom *atom0;
@@ -564,6 +568,8 @@ refresh_crystal(ModeInfo * mi)
 	crystalstruct *cryst = &crystals[MI_SCREEN(mi)];
 	int         i;
 
+	if (!cryst->painted)
+		return;
 	MI_CLEARWINDOW(mi);
 	XSetFunction(display, cryst->gc, GXxor);
 
@@ -688,10 +694,11 @@ init_crystal(ModeInfo * mi)
 	}
 /* Clear Display */
 	MI_CLEARWINDOW(mi);
+	cryst->painted = False;
 	XSetFunction(display, cryst->gc, GXxor);
 
 /*Set up crystal data */
-	if (MI_WIN_IS_FULLRANDOM(mi)) {
+	if (MI_IS_FULLRANDOM(mi)) {
 		if (LRAND() & 1)
 			cryst->unit_cell = True;
 		else
@@ -699,7 +706,7 @@ init_crystal(ModeInfo * mi)
 	} else
 		cryst->unit_cell = unit_cell;
 	if (cryst->unit_cell) {
-		if (MI_WIN_IS_FULLRANDOM(mi)) {
+		if (MI_IS_FULLRANDOM(mi)) {
 			if (LRAND() & 1)
 				cryst->grid_cell = True;
 			else
@@ -707,12 +714,12 @@ init_crystal(ModeInfo * mi)
 		} else
 			cryst->grid_cell = grid_cell;
 	}
-	cryst->win_width = MI_WIN_WIDTH(mi);
-	cryst->win_height = MI_WIN_HEIGHT(mi);
+	cryst->win_width = MI_WIDTH(mi);
+	cryst->win_height = MI_HEIGHT(mi);
 	cell_min = min(cryst->win_width / 2 + 1, MIN_CELL);
 	cell_min = min(cell_min, cryst->win_height / 2 + 1);
 	cryst->planegroup = NRAND(17);
-	if (MI_WIN_IS_VERBOSE(mi))
+	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout, "Selected plane group no %d\n",
 			       cryst->planegroup + 1);
 	if (cryst->planegroup > 11)
@@ -744,8 +751,8 @@ init_crystal(ModeInfo * mi)
 		cryst->ny = DEF_NY1;
 	neqv = neqv * cryst->nx * cryst->ny;
 
-	cryst->num_atom = MI_BATCHCOUNT(mi);
-	max_atoms = MI_BATCHCOUNT(mi);
+	cryst->num_atom = MI_COUNT(mi);
+	max_atoms = MI_COUNT(mi);
 	if (cryst->num_atom == 0) {
 		cryst->num_atom = DEF_NUM_ATOM;
 		max_atoms = DEF_NUM_ATOM;
