@@ -37,9 +37,11 @@ static const char sccsid[] = "@(#)drift.c	4.07 97/11/24 xlockmore";
 #define drift_opts xlockmore_opts
 #define DEFAULTS "*delay: 10000 \n" \
  "*count: 30 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*fullrandom: True \n"
 #define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
@@ -230,7 +232,7 @@ initmode(ModeInfo * mi, int mode)
 		dp->rainbow = dp->color;
 		dp->fractal_len = 2000000;
 	}
-	dp->fractal_len = (dp->fractal_len * MI_BATCHCOUNT(mi)) / 20;
+	dp->fractal_len = (dp->fractal_len * MI_COUNT(mi)) / 20;
 
 	MI_CLEARWINDOW(mi);
 }
@@ -321,12 +323,12 @@ init_drift(ModeInfo * mi)
 	}
 	dp = &drifts[MI_SCREEN(mi)];
 
-	dp->width = MI_WIN_WIDTH(mi);
-	dp->height = MI_WIN_HEIGHT(mi);
+	dp->width = MI_WIDTH(mi);
+	dp->height = MI_HEIGHT(mi);
 	dp->color = MI_NPIXELS(mi) > 2;
 
-	if (MI_WIN_IS_FULLRANDOM(mi)) {
-		if (LRAND() & 1)
+	if (MI_IS_FULLRANDOM(mi)) {
+		if (NRAND(3) == 0)
 			dp->grow = True;
 		else {
 			dp->grow = False;
@@ -588,8 +590,15 @@ draw_drift(ModeInfo * mi)
 		draw(mi, dp, window);
 		if (dp->total_points++ > dp->fractal_len) {
 			draw_flush(mi, dp, window);
-			if (0 == --dp->nfractals)
+			if (0 == --dp->nfractals) {
+#ifdef STANDALONE
+				XSync(MI_DISPLAY(mi), False);
+				sleep(4);	/* #### make settable */
+				erase_full_window(MI_DISPLAY(mi), window);
+#endif /* STANDALONE */
+
 				initmode(mi, frandom(2));
+			}
 			initfractal(mi);
 		}
 		dp->timer--;
