@@ -41,7 +41,8 @@ static const char sccsid[] = "@(#)flame.c	4.07 97/11/24 xlockmore";
  "*count: 20 \n" \
  "*cycles: 10000 \n" \
  "*ncolors: 200 \n"
-#define SPREAD_COLORS
+#define UNIFORM_COLORS
+#define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -266,10 +267,10 @@ init_flame(ModeInfo * mi)
 	}
 	fp = &flames[MI_SCREEN(mi)];
 
-	fp->width = MI_WIN_WIDTH(mi);
-	fp->height = MI_WIN_HEIGHT(mi);
+	fp->width = MI_WIDTH(mi);
+	fp->height = MI_HEIGHT(mi);
 
-	fp->max_levels = MI_BATCHCOUNT(mi);
+	fp->max_levels = MI_COUNT(mi);
 	fp->cycles = MI_CYCLES(mi);
 
 	MI_CLEARWINDOW(mi);
