@@ -40,7 +40,7 @@ static const char sccsid[] = "@(#)flow.c 4.10 98/04/24 xlockmore";
 #define DEFAULTS "*delay: 1000 \n" \
  "*count: 1024 \n" \
  "*cycles: 3000 \n" \
- "*ncolors: 100 \n"
+ "*ncolors: 200 \n"
 #define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #include "erase.h"
@@ -97,17 +97,16 @@ typedef struct {
 	double      dtheta;
 	double      phi;
 	double      dphi;
-	void        (*ODE) ();
+	void        (*ODE) (Par par, double *dx, double *dy, double *dz,
+        double x, double y, double z, double t);
 	Par         par;
 } flowstruct;
 
 static flowstruct *flows = NULL;
 
 static void
-Lorentz(par, dx, dy, dz, x, y, z)
-	Par         par;
-	double     *dx, *dy, *dz;
-	double      x, y, z;
+Lorentz(Par par, double *dx, double *dy, double *dz,
+        double x, double y, double z, double t)
 {
 	*dx = par.a * (y - x);
 	*dy = x * (par.b - z) - y;
@@ -115,10 +114,8 @@ Lorentz(par, dx, dy, dz, x, y, z)
 }
 
 static void
-Rossler(par, dx, dy, dz, x, y, z)
-	Par         par;
-	double     *dx, *dy, *dz;
-	double      x, y, z;
+Rossler(Par par, double *dx, double *dy, double *dz,
+        double x, double y, double z, double t)
 {
 	*dx = -(y + par.a * z);
 	*dy = x + y * par.b;
@@ -126,10 +123,8 @@ Rossler(par, dx, dy, dz, x, y, z)
 }
 
 static void
-RosslerCone(par, dx, dy, dz, x, y, z)
-	Par         par;
-	double     *dx, *dy, *dz;
-	double      x, y, z;
+RosslerCone(Par par, double *dx, double *dy, double *dz,
+            double x, double y, double z, double t)
 {
 	*dx = -(y + par.a * z);
 	*dy = x + y * par.b - z * z * par.c;
@@ -137,10 +132,8 @@ RosslerCone(par, dx, dy, dz, x, y, z)
 }
 
 static void
-Bagel(par, dx, dy, dz, x, y, z, t)
-	Par         par;
-	double     *dx, *dy, *dz;
-	double      x, y, z, t;
+Bagel(Par par, double *dx, double *dy, double *dz,
+      double x, double y, double z, double t)
 {
 	*dx = -y + par.b * sin(par.c * t);
 	*dy = 0.7 * x + par.a * y * (0.1 - x * x);
@@ -373,7 +366,13 @@ draw_flow(ModeInfo * mi)
 					      sp->cnsegs[col]);
 			}
 		}
-	}
+	} else {
+		/* mono */
+		XSetForeground(display, gc, MI_PIXEL(mi, 1));
+		XDrawSegments(display, window, gc,
+			sp->csegs + col * sp->beecount, sp->cnsegs[col]);
+  }
+
 	for (col = 0, c = 0; col < MI_NPIXELS(mi); col++)
 		for (b = 0; b < sp->cnsegs[col]; b++) {
 			XSegment    s = (sp->csegs + col * sp->beecount)[b];
