@@ -85,7 +85,8 @@ static const char sccsid[] = "@(#)cage.c	4.07 98/01/04 xlockmore";
 #define HACK_INIT init_cage
 #define HACK_DRAW draw_cage
 #define cage_opts xlockmore_opts
-#define DEFAULTS "*delay: 1000 \n"
+#define DEFAULTS "*delay: 1000 \n" \
+ "*wireframe: False \n"
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
@@ -316,7 +317,7 @@ reshape(ModeInfo * mi, int width, int height)
 }
 
 static void
-pinit()
+pinit(void)
 {
 	glClearDepth(1.0);
 	glClearColor(0.0, 0.0, 0.0, 1.0);
