@@ -575,7 +575,7 @@ reshape(ModeInfo * mi, int width, int height)
 }
 
 static void
-pinit()
+pinit(void)
 {
 	glClearDepth(1.0);
 	glClearColor(0.0, 0.0, 0.0, 1.0);
