@@ -126,9 +126,10 @@ static const char sccsid[] = "@(#)rubik.c	4.07 97/11/24 xlockmore";
 #define HACK_INIT init_rubik
 #define HACK_DRAW draw_rubik
 #define rubik_opts xlockmore_opts
-#define DEFAULTS "*delay: 1000 \n" \
- "*count: 50 \n" \
- "*cycles: 1 \n"
+#define DEFAULTS "*delay: 40000 \n" \
+ "*count: -30 \n" \
+ "*cycles: 5 \n" \
+ "*size: -6 \n"
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
@@ -164,7 +165,7 @@ ModeSpecOpt rubik_opts =
 ModStruct   rubik_description =
 {"rubik", "init_rubik", "draw_rubik", "release_rubik",
  "draw_rubik", "change_rubik", NULL, &rubik_opts,
- 1000, -30, 5, -6, 4, 1.0, "",
+ 10000, -30, 5, -6, 4, 1.0, "",
  "Shows an auto-solving Rubik's Cube", 0, NULL};
 
 #endif
