@@ -67,7 +67,7 @@ static const char sccsid[] = "@(#)stairs.c	4.07 97/11/24 xlockmore";
 #define HACK_INIT init_stairs
 #define HACK_DRAW draw_stairs
 #define stairs_opts xlockmore_opts
-#define DEFAULTS "*delay: 1000 \n"
+#define DEFAULTS "*delay: 200000 \n"
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
@@ -349,7 +349,7 @@ reshape(ModeInfo * mi, int width, int height)
 }
 
 static void
-pinit()
+pinit(void)
 {
 	glClearDepth(1.0);
 	glClearColor(0.0, 0.0, 0.0, 1.0);
