@@ -34,7 +34,7 @@ static const char sccsid[] = "@(#)laser.c	4.07 97/11/24 xlockmore";
  "*count: -10 \n" \
  "*cycles: 200 \n" \
  "*ncolors: 200 \n"
-#define SMOOTH_COLORS
+#define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -116,11 +116,11 @@ init_laser(ModeInfo * mi)
 	}
 	lp = &lasers[MI_SCREEN(mi)];
 
-	lp->width = MI_WIN_WIDTH(mi);
-	lp->height = MI_WIN_HEIGHT(mi);
+	lp->width = MI_WIDTH(mi);
+	lp->height = MI_HEIGHT(mi);
 	lp->time = 0;
 
-	lp->ln = MI_BATCHCOUNT(mi);
+	lp->ln = MI_COUNT(mi);
 	if (lp->ln < -MINLASER) {
 		/* if lp->ln is random ... the size can change */
 		if (lp->laser != NULL) {
@@ -330,5 +330,5 @@ release_laser(ModeInfo * mi)
 void
 refresh_laser(ModeInfo * mi)
 {
-	/* Do nothing, it will refresh by itself */
+	MI_CLEARWINDOW(mi);
 }
