@@ -53,9 +53,12 @@ static const char sccsid[] = "@(#)life1d.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 10000 \n" \
  "*cycles: 10 \n" \
  "*size: 0 \n" \
- "*ncolors: 200 \n"
-#define DEF_BITMAP ""
+ "*ncolors: 200 \n" \
+ "*bitmap: \n" \
+ "*verbose: \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
+#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
@@ -551,15 +554,18 @@ init_stuff(ModeInfo * mi)
 			 DEFAULT_XPM, CELL_NAME,
 #endif
 			 &lp->graphics_format, &lp->cmap, &lp->black);
+#ifndef STANDALONE
 	if (lp->cmap != None) {
-		setColormap(display, window, lp->cmap, MI_WIN_IS_INWINDOW(mi));
+		setColormap(display, window, lp->cmap, MI_IS_INWINDOW(mi));
 		if (lp->backGC == None) {
 			XGCValues   xgcv;
 
 			xgcv.background = lp->black;
 			lp->backGC = XCreateGC(display, window, GCBackground, &xgcv);
 		}
-	} else {
+	} else
+#endif /* STANDALONE */
+	{
 		lp->black = MI_BLACK_PIXEL(mi);
 		lp->backGC = MI_GC(mi);
 	}
@@ -630,8 +636,8 @@ init_life1d(ModeInfo * mi)
 		(void) free((void *) lp->oldcells);
 	if (lp->buffer != NULL)
 		(void) free((void *) lp->buffer);
-	lp->width = MI_WIN_WIDTH(mi);
-	lp->height = MI_WIN_HEIGHT(mi);
+	lp->width = MI_WIDTH(mi);
+	lp->height = MI_HEIGHT(mi);
 	if (lp->width < 2)
 		lp->width = 2;
 	if (lp->height < 2)
@@ -675,7 +681,7 @@ init_life1d(ModeInfo * mi)
 	lp->yb = (lp->height - lp->ys * lp->nrows) / 2;
 
 	GetRule(lp, (int) NRAND((totalistic) ? TOTALISTICRULES : LCAURULES));
-	if (MI_WIN_IS_VERBOSE(mi)) {
+	if (MI_IS_VERBOSE(mi)) {
 		(void) fprintf(stdout, "colors %d, radius %d, code %ld, ",
 			       lp->k, lp->r, lp->code);
 		if (totalistic) {
