@@ -50,6 +50,8 @@ static const char sccsid[] = "@(#)life3d.c	4.07 98/01/18 xlockmore";
  "*count: 35 \n" \
  "*cycles: 85 \n" \
  "*ncolors: 200 \n" \
+ "*wireframe: False \n" \
+ "*fullrandom: False \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #include "iostuff.h"
@@ -156,7 +158,6 @@ typedef struct {
 	Bool        painted;
 	paramstruct param;
 	int         pattern, patterned_rule;
-	int         wireframe;	/* FALSE */
 	int         ox, oy, oz;	/* origin */
 	double      vx, vy, vz;	/* viewpoint */
 	int         generation;
@@ -171,6 +172,7 @@ typedef struct {
 	double      dist;
 	CellList   *ptrhead, *ptrend, eraserhead, eraserend;
 	CellList   *buckethead[NBUCKETS], *bucketend[NBUCKETS];		/* comfortable upper b */
+	Bool        wireframe;
 } life3dstruct;
 
 static life3dstruct *life3ds = NULL;
@@ -1881,7 +1883,9 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 		XFillPolygon(display, MI_WINDOW(mi), gc, facepts, 4,
 			     Convex, CoordModeOrigin);
 	}
-	if (color == BLACK || (MI_NPIXELS(mi) <= 2 && !lp->wireframe))
+	if (lp->wireframe) {
+		XSetForeground(display, gc, lp->color[color]);
+	} else if (color == BLACK)
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	else
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
@@ -1926,6 +1930,20 @@ DrawCube(ModeInfo * mi, CellList * cell)
 	dx = lp->vx - x;
 	dy = lp->vy - y;
 	dz = lp->vz - z;
+	if (lp->wireframe) {
+		if (dz <= LEN)
+			DrawFace(mi, (int) (BLUE & mask), cubepts, 4, 5, 7, 6);
+		else if (dz >= -LEN)
+			DrawFace(mi, (int) (BLUE & mask), cubepts, 0, 1, 3, 2);
+		if (dx <= LEN)
+			DrawFace(mi, (int) (GREEN & mask), cubepts, 1, 3, 7, 5);
+		else if (dx >= -LEN)
+			DrawFace(mi, (int) (GREEN & mask), cubepts, 0, 2, 6, 4);
+		if (dy <= LEN)
+			DrawFace(mi, (int) (RED & mask), cubepts, 2, 3, 7, 6);
+		else if (dy >= -LEN)
+			DrawFace(mi, (int) (RED & mask), cubepts, 0, 1, 5, 4);
+	}
 	if (dz > LEN)
 		DrawFace(mi, (int) (BLUE & mask), cubepts, 4, 5, 7, 6);
 	else if (dz < -LEN)
@@ -2140,7 +2158,7 @@ init_life3d(ModeInfo * mi)
 		lp->ox = lp->ncolumns / 2;
 		lp->oy = lp->nrows / 2;
 		lp->oz = lp->nstacks / 2;
-		lp->wireframe = 0;
+
 		Init3D(lp);
 	} else
 		End3D(lp);
@@ -2163,6 +2181,12 @@ init_life3d(ModeInfo * mi)
 	lp->memstart = 1;
 	/*lp->tablesMade = 0; */
 
+	if (MI_IS_FULLRANDOM(mi)) {
+		lp->wireframe = (Bool) (LRAND() & 1);
+	} else {
+		lp->wireframe = MI_IS_WIREFRAME(mi);
+	}
+
 	MI_CLEARWINDOW(mi);
 	lp->painted = False;
 
