@@ -522,8 +522,8 @@ init_lightning(ModeInfo * mi)
 	}
 	st = &Helga[MI_SCREEN(mi)];
 
-	st->scr_width = MI_WIN_WIDTH(mi);
-	st->scr_height = MI_WIN_HEIGHT(mi);
+	st->scr_width = MI_WIDTH(mi);
+	st->scr_height = MI_HEIGHT(mi);
 
 	st->multi_strike = setup_multi_strike();
 	random_storm(st);
