@@ -40,8 +40,9 @@ static const char sccsid[] = "@(#)lissie.c	4.07 97/11/24 xlockmore";
  "*cycles: 20000 \n" \
  "*size: -200 \n" \
  "*ncolors: 200 \n"
-#define BRIGHT_COLORS
+#define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
@@ -95,6 +96,7 @@ typedef struct {
 } lissiestruct;
 
 typedef struct {
+	Bool        painted;
 	int         width, height;
 	int         nlissies;
 	lissiestruct *lissie;
@@ -224,10 +226,10 @@ init_lissie(ModeInfo * mi)
 	}
 	lp = &lisses[MI_SCREEN(mi)];
 
-	lp->width = MI_WIN_WIDTH(mi);
-	lp->height = MI_WIN_HEIGHT(mi);
+	lp->width = MI_WIDTH(mi);
+	lp->height = MI_HEIGHT(mi);
 
-	lp->nlissies = MI_BATCHCOUNT(mi);
+	lp->nlissies = MI_COUNT(mi);
 	if (lp->nlissies < -MINLISSIES) {
 		if (lp->lissie) {
 			(void) free((void *) lp->lissie);
@@ -243,6 +245,7 @@ init_lissie(ModeInfo * mi)
 		lp->lissie = (lissiestruct *) calloc(lp->nlissies, sizeof (lissiestruct));
 
 	MI_CLEARWINDOW(mi);
+	lp->painted = False;
 
 	for (ball = 0; ball < (unsigned char) lp->nlissies; ball++)
 		initlissie(mi, &lp->lissie[ball]);
@@ -255,11 +258,16 @@ draw_lissie(ModeInfo * mi)
 	lissstruct *lp = &lisses[MI_SCREEN(mi)];
 	register unsigned char ball;
 
-	if (++lp->loopcount > MI_CYCLES(mi))
+	if (++lp->loopcount > MI_CYCLES(mi)) {
+#ifdef STANDALONE
+		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
+#endif
 		init_lissie(mi);
-	else
+	} else {
+		lp->painted = True;
 		for (ball = 0; ball < (unsigned char) lp->nlissies; ball++)
 			drawlissie(mi, &lp->lissie[ball]);
+	}
 }
 
 void
@@ -288,9 +296,12 @@ refresh_lissie(ModeInfo * mi)
 		lissstruct *lp = &lisses[MI_SCREEN(mi)];
 		int         i;
 
-		for (i = 0; i < lp->nlissies; i++) {
-			lp->lissie[i].redrawing = 1;
-			lp->lissie[i].redrawpos = 0;
+		if (lp->painted) {
+			MI_CLEARWINDOW(mi);
+			for (i = 0; i < lp->nlissies; i++) {
+				lp->lissie[i].redrawing = 1;
+				lp->lissie[i].redrawpos = 0;
+			}
 		}
 	}
 }
