@@ -34,7 +34,8 @@ static const char sccsid[] = "@(#)mountain.c	4.07 97/11/24 xlockmore";
  "*count: 30 \n" \
  "*cycles: 4000 \n" \
  "*ncolors: 64 \n" \
- "*wireframe: False \n"
+ "*wireframe: False \n" \
+ "*fullrandom: False \n"
 #define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
@@ -70,6 +71,8 @@ typedef struct {
 	int         h[WORLDWIDTH][WORLDWIDTH];
 	int         time;	/* up time */
 	int         first;
+	Bool        wireframe;
+	Bool        joke;
 	GC          stippled_GC;
 } mountainstruct;
 
@@ -128,14 +131,26 @@ drawamountain(ModeInfo * mi)
 	else
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 
-	if (MI_IS_WIREFRAME(mi)) {
-		XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
-	} else {
-		XFillPolygon(display, window, gc, p, 4, Complex, CoordModeOrigin);
-
-		if (!mp->pixelmode) {
-			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+	if (mp->joke) {
+		if ((Bool) (LRAND() & 1))
 			XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+		else {
+			XFillPolygon(display, window, gc, p, 4, Complex, CoordModeOrigin);
+			if (!mp->pixelmode) {
+				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+			}
+		}
+	} else {
+		if (mp->wireframe) {
+			XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+		} else {
+			XFillPolygon(display, window, gc, p, 4, Complex, CoordModeOrigin);
+
+			if (!mp->pixelmode) {
+				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+				XDrawLines(display, window, gc, p, 5, CoordModeOrigin);
+			}
 		}
 	}
 	mp->x++;
@@ -166,6 +181,14 @@ init_mountain(ModeInfo * mi)
 	mp->stage = 0;
 	mp->time = 0;
 	mp->x = mp->y = 0;
+	if (MI_IS_FULLRANDOM(mi)) {
+		mp->joke = (Bool) (NRAND(10) == 0);
+		mp->wireframe = (Bool) (LRAND() & 1);
+	} else {
+		mp->joke = False;
+		mp->wireframe = MI_IS_WIREFRAME(mi);
+	}
+
 	if (!mp->first) {
 		mp->first = 1;
 		gcv.foreground = MI_WHITE_PIXEL(mi);
