@@ -49,7 +49,8 @@ static const char sccsid[] = "@(#)petal.c	4.07 97/11/24 xlockmore";
  "*count: -500 \n" \
  "*cycles: 400 \n" \
  "*ncolors: 64 \n" \
- "*wireframe: False \n"
+ "*wireframe: False \n" \
+ "*fullrandom: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -90,6 +91,7 @@ typedef struct {
 	int         npoints;
 	long        color;
 	XPoint     *points;
+        Bool        wireframe;
 } petalstruct;
 
 static petalstruct *petals = NULL;
@@ -245,7 +247,7 @@ petal(ModeInfo * mi)
 	petalstruct *pp = &petals[MI_SCREEN(mi)];
 
 	XSetForeground(MI_DISPLAY(mi), MI_GC(mi), pp->color);
-  if (MI_IS_WIREFRAME(mi)) {
+        if (pp->wireframe) {
 		XDrawLines(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			     pp->points, pp->npoints + 1, CoordModeOrigin);
 	} else {
@@ -298,6 +300,10 @@ init_petal(ModeInfo * mi)
 	pp->height = MI_HEIGHT(mi);
 
 	pp->time = 0;
+        if (MI_IS_FULLRANDOM(mi))
+          pp->wireframe = (Bool) (LRAND() & 1 );
+        else
+            pp->wireframe = MI_IS_WIREFRAME(mi);
 
 	MI_CLEARWINDOW(mi);
 	pp->painted = False;
