@@ -114,8 +114,9 @@ extern char *bitmap;
 #ifdef USE_GL
 static char gl_modes[][MAXMODECHARS] =
 {
-	"cage", "gears", "moebius", "morph3d", "pipes", "rubik",
-	"sproingies", "stairs", "superquadrics"
+    "atlantis", "cage", "gears", "bubble3d",
+	"moebius", "morph3d", "pipes", "rubik",
+    "sproingies", "stairs", "superquadrics"
 };
 
 #define NUMGL (sizeof (gl_modes) / sizeof (gl_modes[0]))
