@@ -39,7 +39,9 @@ static const char sccsid[] = "@(#)sierpinski.c	4.07 97/11/24 xlockmore";
 #define sierpinski_opts xlockmore_opts
 #define DEFAULTS "*delay: 400000 \n" \
  "*count: 2000 \n" \
- "*cycles: 100 \n"
+ "*cycles: 100 \n" \
+ "*ncolors: 64 \n"
+#define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -122,10 +124,10 @@ init_sierpinski(ModeInfo * mi)
 	}
 	sp = &tris[MI_SCREEN(mi)];
 
-	sp->width = MI_WIN_WIDTH(mi);
-	sp->height = MI_WIN_HEIGHT(mi);
+	sp->width = MI_WIDTH(mi);
+	sp->height = MI_HEIGHT(mi);
 
-	sp->total_npoints = MI_BATCHCOUNT(mi);
+	sp->total_npoints = MI_COUNT(mi);
 	if (sp->total_npoints < 1)
 		sp->total_npoints = 1;
 	sp->corners = MI_SIZE(mi);
@@ -193,5 +195,5 @@ release_sierpinski(ModeInfo * mi)
 void
 refresh_sierpinski(ModeInfo * mi)
 {
-	/* Do nothing, it will refresh by itself */
+	MI_CLEARWINDOW(mi);
 }
