@@ -64,7 +64,7 @@ static const char sccsid[] = "@(#)sphere.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 5000 \n" \
  "*cycles: 20 \n" \
  "*size: 0 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 64 \n"
 #define BRIGHT_COLORS
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
@@ -123,8 +123,8 @@ init_sphere(ModeInfo * mi)
 		(void) free((void *) sp->points);
 		sp->points = NULL;
 	}
-	sp->width = MI_WIN_WIDTH(mi);
-	sp->height = MI_WIN_HEIGHT(mi);
+	sp->width = MI_WIDTH(mi);
+	sp->height = MI_HEIGHT(mi);
 	sp->points = (XPoint *) malloc(sp->height * sizeof (XPoint));
 
 	MI_CLEARWINDOW(mi);
