@@ -1259,8 +1259,8 @@ init_swirl(ModeInfo * mi)
 
 	/* get window parameters */
 	swirl->win = window;
-	swirl->width = MI_WIN_WIDTH(mi);
-	swirl->height = MI_WIN_HEIGHT(mi);
+	swirl->width = MI_WIDTH(mi);
+	swirl->height = MI_HEIGHT(mi);
 	swirl->depth = MI_DEPTH(mi);
 	swirl->rdepth = swirl->depth;
 	swirl->visual = MI_VISUAL(mi);
@@ -1290,7 +1290,7 @@ init_swirl(ModeInfo * mi)
 	/* attach the colour map to the window (if we have one) */
 	if (!swirl->fixed_colourmap) {
 #if 1
-		setColormap(display, window, swirl->cmap, MI_WIN_IS_INWINDOW(mi));
+		setColormap(display, window, swirl->cmap, MI_IS_INWINDOW(mi));
 #else
 		XSetWindowColormap(display, window, swirl->cmap);
 		XSetWMColormapWindows(display, window, &window, 1);
@@ -1306,8 +1306,8 @@ init_swirl(ModeInfo * mi)
 	swirl->r = (1 << (swirl->resolution - 1));
 
 	/* how many knots? */
-	swirl->n_knots = random_no((unsigned int) MI_BATCHCOUNT(mi) / 2) +
-		MI_BATCHCOUNT(mi) + 1;
+	swirl->n_knots = random_no((unsigned int) MI_COUNT(mi) / 2) +
+		MI_COUNT(mi) + 1;
 
 	/* what type of knots? */
 	swirl->knot_type = ALL;	/* for now */
@@ -1463,6 +1463,7 @@ refresh_swirl(ModeInfo * mi)
 	SWIRL_P     swirl = &(swirls[MI_SCREEN(mi)]);
 
 	if (swirl->started) {
+		MI_CLEARWINDOW(mi);
 		if (swirl->drawing)
 			swirl->resolution = swirl->resolution + 1;
 		swirl->drawing = False;
