@@ -51,8 +51,11 @@ static const char sccsid[] = "@(#)vines.c	4.07 97/11/24 xlockmore";
 #define vines_opts xlockmore_opts
 #define DEFAULTS "*delay: 200000 \n" \
  "*count: 0 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 64 \n" \
+ "*eraseSpeed: 400 \n" \
+ "*eraseMode: -1 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
@@ -89,6 +92,7 @@ static vinestruct *vines = NULL;
 void
 refresh_vines(ModeInfo * mi)
 {
+	MI_CLEARWINDOW(mi);
 }				/* refresh_vines */
 
 void
@@ -120,11 +124,14 @@ draw_vines(ModeInfo * mi)
 	int         count;
 
 	if (fp->i >= fp->length) {
-		if (--(fp->iterations) == 0)
+		if (--(fp->iterations) == 0) {
+#ifdef STANDALONE
+			erase_full_window(display, MI_WINDOW(mi));
+#endif /* STANDALONE */
 			init_vines(mi);
-
-		fp->centerx = NRAND(MI_WIN_WIDTH(mi));
-		fp->centery = NRAND(MI_WIN_HEIGHT(mi));
+		}
+		fp->centerx = NRAND(MI_WIDTH(mi));
+		fp->centery = NRAND(MI_HEIGHT(mi));
 
 		fp->ang = 60 + NRAND(720);
 		fp->length = 100 + NRAND(3000);
@@ -142,7 +149,7 @@ draw_vines(ModeInfo * mi)
 		else
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 	}
-	count = fp->i + MI_BATCHCOUNT(mi);
+	count = fp->i + MI_COUNT(mi);
 	if ((count <= fp->i) || (count > fp->length))
 		count = fp->length;
 
