@@ -38,12 +38,19 @@ static const char sccsid[] = "@(#)wator.c	4.07 97/11/24 xlockmore";
 #define DEFAULTS "*delay: 750000 \n" \
  "*cycles: 32767 \n" \
  "*size: 0 \n" \
- "*ncolors: 200 \n"
+ "*ncolors: 200 \n" \
+ "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
+#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+/*-
+ * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
+ */
+extern int  neighbors;
+
 ModeSpecOpt wator_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -56,8 +63,6 @@ ModStruct   wator_description =
 
 #endif
 
-extern int  neighbors;
-
 #include "bitmaps/fish-0.xbm"
 #include "bitmaps/fish-1.xbm"
 #include "bitmaps/fish-2.xbm"
@@ -120,7 +125,7 @@ typedef struct _CellList {
 } CellList;
 
 typedef struct {
-	int         initialized;
+	Bool        painted;
 	int         nkind[KINDS];	/* Number of fish and sharks */
 	int         breed[KINDS];	/* Breeding time of fish and sharks */
 	int         sstarve;	/* Time the sharks starve if they dont find a fish */
@@ -598,10 +603,9 @@ init_wator(ModeInfo * mi)
 	wp = &wators[MI_SCREEN(mi)];
 
 	wp->generation = 0;
-	if (!wp->initialized) {	/* Genesis */
+	if (!wp->firstkind[0]) {	/* Genesis */
 		icon_width = fish0_width;
 		icon_height = fish0_height;
-		wp->initialized = 1;
 		/* Set up what will be a 'triply' linked list.
 		   doubly linked list, doubly linked to an array */
 		for (kind = FISH; kind <= KINDS; kind++)
@@ -615,8 +619,8 @@ init_wator(ModeInfo * mi)
 		for (i = FISH; i <= KINDS; i++)
 			flush_kindlist(wp, i);
 
-	wp->width = MI_WIN_WIDTH(mi);
-	wp->height = MI_WIN_HEIGHT(mi);
+	wp->width = MI_WIDTH(mi);
+	wp->height = MI_HEIGHT(mi);
 	if (wp->width < 2)
 		wp->width = 2;
 	if (wp->height < 2)
@@ -747,7 +751,7 @@ init_wator(ModeInfo * mi)
 	wp->kind = FISH;
 	if (!wp->nkind[SHARK])
 		wp->nkind[SHARK] = 1;
-	wp->breed[FISH] = MI_BATCHCOUNT(mi);
+	wp->breed[FISH] = MI_COUNT(mi);
 	wp->breed[SHARK] = 10;
 	if (wp->breed[FISH] < 1)
 		wp->breed[FISH] = 1;
@@ -756,6 +760,7 @@ init_wator(ModeInfo * mi)
 	wp->sstarve = 3;
 
 	MI_CLEARWINDOW(mi);
+	wp->painted = False;
 
 	for (kind = FISH; kind <= SHARK; kind++) {
 		i = 0;
@@ -797,6 +802,7 @@ draw_wator(ModeInfo * mi)
 	} acell[12];
 
 
+	wp->painted = True;
 	/* Alternate updates, fish and sharks live out of phase with each other */
 	wp->kind = (wp->kind + 1) % KINDS;
 	{
@@ -937,9 +943,12 @@ release_wator(ModeInfo * mi)
 			watorstruct *wp = &wators[screen];
 
 			for (kind = 0; kind <= KINDS; kind++) {
-				flush_kindlist(wp, kind);
-				(void) free((void *) wp->lastkind[kind]);
-				(void) free((void *) wp->firstkind[kind]);
+				if (wp->firstkind[0])
+					flush_kindlist(wp, kind);
+				if (wp->lastkind[kind])
+					(void) free((void *) wp->lastkind[kind]);
+				if (wp->firstkind[kind])
+					(void) free((void *) wp->firstkind[kind]);
 			}
 			if (wp->arr != NULL)
 				(void) free((void *) wp->arr);
@@ -952,5 +961,10 @@ release_wator(ModeInfo * mi)
 void
 refresh_wator(ModeInfo * mi)
 {
-	/* Do nothing, it will refresh by itself */
+	watorstruct *wp = &wators[MI_SCREEN(mi)];
+
+	if (wp->painted) {
+		MI_CLEARWINDOW(mi);
+		wp->painted = False;
+	}
 }
