@@ -1,6 +1,9 @@
 static char *LockProcs[] =
 {
 	"ant",
+#ifdef USE_GL
+	"atlantis",
+#endif
 	"ball",
 	"bat",
 	"blot",
@@ -8,6 +11,9 @@ static char *LockProcs[] =
 	"bounce",
 	"braid",
 	"bubble",
+#ifdef USE_GL
+	"bubbles3d",
+#endif
 	"bug",
 #ifdef USE_GL
 	"cage",
