@@ -40,6 +40,12 @@ LockStruct  LockProcs[] =
 	 refresh_ant, init_ant, NULL, &ant_opts,
 	 1000, -3, 40000, -7, 64, 1.0, "",
 	 "Shows Langton's and Turk's generalized ants", 0, NULL},
+#ifdef USE_GL
+	{"atlantis", init_atlantis, draw_atlantis, release_atlantis,
+	 refresh_atlantis, change_atlantis, NULL, &atlantis_opts,
+ 	1000, 4, 100, 6000, 64, 1.0, "",
+ 	"Shows moving sharks/whales/dolphin", 0, NULL},
+#endif
 	{"ball", init_ball, draw_ball, release_ball,
 	 refresh_ball, init_ball, NULL, &ball_opts,
 	 10000, 10, 20, -100, 64, 1.0, "",
@@ -50,7 +56,7 @@ LockStruct  LockProcs[] =
 	 "Shows bouncing flying bats", 0, NULL},
 	{"blot", init_blot, draw_blot, release_blot,
 	 refresh_blot, init_blot, NULL, &blot_opts,
-	 200000, 6, 30, 1, 64, 0.4, "",
+	 200000, 6, 30, 1, 64, 0.3, "",
 	 "Shows Rorschach's ink blot test", 0, NULL},
 	{"bouboule", init_bouboule, draw_bouboule, release_bouboule,
 	 refresh_bouboule, init_bouboule, NULL, &bouboule_opts,
@@ -64,14 +70,20 @@ LockStruct  LockProcs[] =
 	 refresh_braid, init_braid, NULL, &braid_opts,
 	 1000, 15, 100, -7, 64, 1.0, "",
 	 "Shows random braids and knots", 0, NULL},
-	{"bug", init_bug, draw_bug, release_bug,
-	 refresh_bug, init_bug, NULL, &bug_opts,
-	 75000, 10, 32767, -4, 64, 1.0, "",
-	 "Shows Palmiter's bug evolution and garden of Eden", 0, NULL},
 	{"bubble", init_bubble, draw_bubble, release_bubble,
 	 refresh_bubble, init_bubble, NULL, &bubble_opts,
 	 100000, 25, 1, 100, 64, 0.6, "",
 	 "Shows popping bubbles", 0, NULL},
+#if defined( USE_GL ) && defined( USE_UNSTABLE )
+	{"bubble3d", init_bubble3d, draw_bubble3d, release_bubble3d,
+	 draw_bubble3d, change_bubble3d, NULL, &bubble3d_opts,
+	 1000, 1, 2, 1, 64, 1.0, "",
+	 "Richard Jones's GL bubbles", 0, NULL},
+#endif
+	{"bug", init_bug, draw_bug, release_bug,
+	 refresh_bug, init_bug, NULL, &bug_opts,
+	 75000, 10, 32767, -4, 64, 1.0, "",
+	 "Shows Palmiter's bug evolution and garden of Eden", 0, NULL},
 #ifdef USE_GL
 	{"cage", init_cage, draw_cage, release_cage,
 	 draw_cage, change_cage, NULL, &cage_opts,
@@ -90,7 +102,7 @@ LockStruct  LockProcs[] =
 	 "Shows Packard's clock", 0, NULL},
 	{"coral", init_coral, draw_coral, release_coral,
 	 init_coral, init_coral, NULL, &coral_opts,
-	 60000, -3, 1, 35, 64, 0.8, "",
+	 60000, -3, 1, 35, 64, 0.6, "",
 	 "Shows a coral reef", 0, NULL},
 	{"crystal", init_crystal, draw_crystal, release_crystal,
 	 refresh_crystal, init_crystal, NULL, &crystal_opts,
@@ -102,11 +114,11 @@ LockStruct  LockProcs[] =
 	 "Shows a meadow of daisies", 0, NULL},
 	{"dclock", init_dclock, draw_dclock, release_dclock,
 	 refresh_dclock, init_dclock, NULL, &dclock_opts,
-	 10000, 1, 10000, 1, 64, 0.2, "",
+	 10000, 1, 10000, 1, 64, 0.3, "",
 	 "Shows a floating digital clock", 0, NULL},
 	{"deco", init_deco, draw_deco, release_deco,
 	 init_deco, init_deco, NULL, &deco_opts,
-	 1000000, -30, 2, -10, 64, 0.8, "",
+	 1000000, -30, 2, -10, 64, 0.6, "",
 	 "Shows art as ugly as sin", 0, NULL},
 	{"demon", init_demon, draw_demon, release_demon,
 	 refresh_demon, init_demon, NULL, &demon_opts,
@@ -175,9 +187,9 @@ LockStruct  LockProcs[] =
 	 10000, 1000, 2500, 1, 64, 1.0, "",
 	 "Shows real plane iterated fractals", 0, NULL},
 	{"hyper", init_hyper, draw_hyper, release_hyper,
-	 refresh_hyper, init_hyper, NULL, &hyper_opts,
-	 20000, 1, 5000, 1, 64, 1.0, "",
-	 "Shows a spinning tesseract in 4D space", 0, NULL},
+	 refresh_hyper, change_hyper, NULL, &hyper_opts,
+	 100000, -6, 300, 1, 64, 1.0, "",
+	 "Shows spinning n-dimensional hypercubes", 0, NULL},
 	{"ico", init_ico, draw_ico, release_ico,
 	 refresh_ico, change_ico, NULL, &ico_opts,
 	 100000, 0, 400, 0, 64, 1.0, "",
@@ -194,10 +206,10 @@ LockStruct  LockProcs[] =
 	 refresh_julia, init_julia, NULL, &julia_opts,
 	 10000, 1000, 20, 1, 64, 1.0, "",
 	 "Shows the Julia set", 0, NULL},
-	{"kaleid", init_kaleid, draw_kaleid, release_kaleid,
-	 refresh_kaleid, init_kaleid, NULL, &kaleid_opts,
-	 20000, 1, 700, 1, 64, 1.0, "",
-	 "Shows a kaleidoscope", 0, NULL},
+  {"kaleid", init_kaleid, draw_kaleid, release_kaleid,
+   refresh_kaleid, init_kaleid, NULL, &kaleid_opts,
+   80000, 4, 40, -9, 64, 0.6, "",
+   "Shows a kaleidoscope", 0, NULL},
 	{"laser", init_laser, draw_laser, release_laser,
 	 refresh_laser, init_laser, NULL, &laser_opts,
 	 20000, -10, 200, 1, 64, 1.0, "",
@@ -305,12 +317,12 @@ LockStruct  LockProcs[] =
 	 "Shows a rolling ball", 0, NULL},
 	{"rotor", init_rotor, draw_rotor, release_rotor,
 	 refresh_rotor, init_rotor, NULL, &rotor_opts,
-	 10000, 4, 20, -6, 64, 0.4, "",
+	 10000, 4, 20, -6, 64, 0.3, "",
 	 "Shows Tom's Roto-Rooter", 0, NULL},
 #ifdef USE_GL
 	{"rubik", init_rubik, draw_rubik, release_rubik,
 	 draw_rubik, change_rubik, NULL, &rubik_opts,
-	 1000, -30, 5, -6, 64, 1.0, "",
+	 10000, -30, 5, -6, 64, 1.0, "",
 	 "Shows an auto-solving Rubik's Cube", 0, NULL},
 #endif
 	{"shape", init_shape, draw_shape, release_shape,
@@ -335,7 +347,7 @@ LockStruct  LockProcs[] =
 	 "Shows a helical locus of points", 0, NULL},
 	{"spline", init_spline, draw_spline, release_spline,
 	 refresh_spline, init_spline, NULL, &spline_opts,
-	 30000, -6, 2048, 1, 64, 0.4, "",
+	 30000, -6, 2048, 1, 64, 0.3, "",
 	 "Shows colorful moving splines", 0, NULL},
 #ifdef USE_GL
 	{"sproingies", init_sproingies, draw_sproingies, release_sproingies,
@@ -344,12 +356,12 @@ LockStruct  LockProcs[] =
   "Shows Sproingies!  Nontoxic.  Safe for pets and small children", 0, NULL},
 	{"stairs", init_stairs, draw_stairs, release_stairs,
 	 draw_stairs, change_stairs, NULL, &stairs_opts,
-	 1000, 0, 1, 1, 64, 1.0, "",
+	 200000, 0, 1, 1, 64, 1.0, "",
 	 "Shows some Infinite Stairs, an Escher-like scene", 0, NULL},
 #endif
 	{"star", init_star, draw_star, release_star,
 	 refresh_star, init_star, NULL, &star_opts,
-	 75000, 100, 1, 100, 64, 0.2, "",
+	 75000, 100, 1, 100, 64, 0.3, "",
 	 "Shows a star field with a twist", 0, NULL},
 	{"strange", init_strange, draw_strange, release_strange,
 	 init_strange, init_strange, NULL, &strange_opts,
