@@ -78,7 +78,7 @@
 #define MI_NONE_COLOR(MI)	((MI)->threed_none_color)
 #define MI_DELTA3D(MI)		((MI)->threed_delta)
 #define MI_CYCLES(MI)		((MI)->cycles)
-#define MI_BATCHCOUNT(MI)	((MI)->batchcount)
+#define MI_BATCHCOUNT(MI)	((MI)->count)
 #define MI_SIZE(MI)		((MI)->size)
 #define MI_BITMAP(MI)		((MI)->bitmap)
 #define MI_WHITE_PIXEL(MI)	((MI)->white)
@@ -98,11 +98,9 @@
 #define MI_IS_WIREFRAME(MI)	((MI)->wireframe_p)
 #define MI_IS_MOUSE(MI)	((MI)->mouse)
 #define MI_IS_USE3D(MI)	((MI)->threed)
-#define MI_COUNT(MI)	((MI)->batchcount)
+#define MI_COUNT(MI)	((MI)->count)
 #define MI_NCOLORS(MI)    ((MI)->ncolors)
 
-/* #define MI_CLEARWINDOW(mi) XClearWindow(MI_DISPLAY(mi), MI_WINDOW(mi)) */
-#define MI_CLEARWINDOW(mi) MI_CLEARWINDOWCOLOR(mi, MI_BLACK_PIXEL(mi))
 
 #define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
 { \
@@ -113,6 +111,9 @@
 #define MI_CLEARWINDOWCOLOR(mi, pixel) \
  MI_CLEARWINDOWCOLORMAP(mi, MI_GC(mi), pixel)
 
+/* #define MI_CLEARWINDOW(mi) XClearWindow(MI_DISPLAY(mi), MI_WINDOW(mi)) */
+#define MI_CLEARWINDOW(mi) MI_CLEARWINDOWCOLOR(mi, MI_BLACK_PIXEL(mi))
+
 #include "screenhack.h"
 
 typedef struct ModeInfo {
@@ -130,7 +131,7 @@ typedef struct ModeInfo {
 	long        pause;
 	Bool        fullrandom;
 	Bool        verbose;
-	long        batchcount;
+	long        count;
 	long        cycles;
 	long        size;
 	long        ncolors;
@@ -454,6 +455,16 @@ extern ModeHook release_ant;
 extern ModeHook refresh_ant;
 extern ModeSpecOpt ant_opts;
 
+#ifdef USE_GL
+extern ModeHook init_atlantis;
+extern ModeHook draw_atlantis;
+extern ModeHook release_atlantis;
+extern ModeHook refresh_atlantis;
+extern ModeHook change_atlantis;
+extern ModeSpecOpt atlantis_opts;
+
+#endif
+
 extern ModeHook init_ball;
 extern ModeHook draw_ball;
 extern ModeHook release_ball;
@@ -490,18 +501,27 @@ extern ModeHook release_braid;
 extern ModeHook refresh_braid;
 extern ModeSpecOpt braid_opts;
 
-extern ModeHook init_bug;
-extern ModeHook draw_bug;
-extern ModeHook release_bug;
-extern ModeHook refresh_bug;
-extern ModeSpecOpt bug_opts;
-
 extern ModeHook init_bubble;
 extern ModeHook draw_bubble;
 extern ModeHook release_bubble;
 extern ModeHook refresh_bubble;
 extern ModeSpecOpt bubble_opts;
 
+#if defined( USE_GL ) && defined( USE_UNSTABLE )
+extern ModeHook init_bubble3d;
+extern ModeHook draw_bubble3d;
+extern ModeHook release_bubble3d;
+extern ModeHook change_bubble3d;
+extern ModeSpecOpt bubble3d_opts;
+
+#endif
+
+extern ModeHook init_bug;
+extern ModeHook draw_bug;
+extern ModeHook release_bug;
+extern ModeHook refresh_bug;
+extern ModeSpecOpt bug_opts;
+
 #ifdef USE_GL
 extern ModeHook init_cage;
 extern ModeHook draw_cage;
@@ -664,6 +684,7 @@ extern ModeHook init_hyper;
 extern ModeHook draw_hyper;
 extern ModeHook release_hyper;
 extern ModeHook refresh_hyper;
+extern ModeHook change_hyper;
 extern ModeSpecOpt hyper_opts;
 
 extern ModeHook init_ico;
