@@ -13,6 +13,8 @@ static const char sccsid[] = "@(#)resource.c	4.07 97/11/24 xlockmore";
  * Revision History:
  *
  * Changes maintained by David Bagley <bagleyd@bigfoot.com>
+ * 19-Jun-98: batchcount depreciated.  Use count instead.  batchcount still
+ *            works for commandline.
  * 01-May-97: Matthew Rench <mdrench@mtu.edu>
  *            Added DPMS options.
  * 01-Apr-97: Tom Schmidt <tschmidt@micron.com>
@@ -422,7 +424,8 @@ static XrmOptionDescRec genTable[] =
 static XrmOptionDescRec modeTable[] =
 {
 	{"-delay", "*delay", XrmoptionSepArg, (caddr_t) NULL},
-	{"-batchcount", "*batchcount", XrmoptionSepArg, (caddr_t) NULL},
+	{"-batchcount", "*count", XrmoptionSepArg, (caddr_t) NULL},
+	{"-count", "*count", XrmoptionSepArg, (caddr_t) NULL},
 	{"-cycles", "*cycles", XrmoptionSepArg, (caddr_t) NULL},
 	{"-size", "*size", XrmoptionSepArg, (caddr_t) NULL},
 	{"-ncolors", "*ncolors", XrmoptionSepArg, (caddr_t) NULL},
@@ -481,7 +484,8 @@ static OptionStruct opDesc[] =
 	{"-parent", "parent window id (for inwindow)"},
 {"-name resourcename", "class name to use for resources (default is XLock)"},
 	{"-delay usecs", "microsecond delay between screen updates"},
-	{"-batchcount num", "number of things per batch"},
+	{"-batchcount num", "number of things per batch (depreciated)"},
+	{"-count num", "number of things per batch"},
 	{"-cycles num", "number of cycles per batch"},
 	{"-size num", "size of a unit in a mode, default is 0"},
 	{"-ncolors num", "maximum number of colors, default is 64"},
@@ -736,7 +740,7 @@ static argtype genvars[] =
 	{(caddr_t *) & echokeys, "echokeys", "EchoKeys", "off", t_Bool},
     {(caddr_t *) & enablesaver, "enablesaver", "EnableSaver", "off", t_Bool},
 	{(caddr_t *) & resetsaver, "resetsaver", "ResetSaver", "on", t_Bool},
-	{(caddr_t *) & fullrandom, "fullrandom", "FullRandom", "off", t_Bool},
+	{(caddr_t *) & fullrandom, "fullrandom", "FullRandom", "on", t_Bool},
 	{(caddr_t *) & grabmouse, "grabmouse", "GrabMouse", "on", t_Bool},
 	{(caddr_t *) & grabserver, "grabserver", "GrabServer", "off", t_Bool},
 	{(caddr_t *) & install, "install", "Install", "on", t_Bool},
@@ -841,7 +845,7 @@ static argtype genvars[] =
 static argtype modevars[] =
 {
 	{(caddr_t *) & delay, "delay", "Delay", DEF_DELAY, t_Int},
-	{(caddr_t *) & count, "batchcount", "BatchCount", DEF_COUNT, t_Int},
+	{(caddr_t *) & count, "count", "Count", DEF_COUNT, t_Int},
 	{(caddr_t *) & cycles, "cycles", "Cycles", DEF_CYCLES, t_Int},
 	{(caddr_t *) & size, "size", "Size", DEF_SIZE, t_Int},
 	{(caddr_t *) & ncolors, "ncolors", "NColors", DEF_NCOLORS, t_Int},
