@@ -77,7 +77,14 @@ VirtualRootWindowOfScreen(Screen * screen)
 		root = RootWindowOfScreen(screen);
 
 		/* go look for a virtual root */
-		if (inroot) {
+#ifndef XSCREENSAVER 
+/*-
+ * Without this it makes the screen all white when xautolock kicks in.
+ * With this it screws up the mouse focus with xscreensaver.
+ */
+		if (inroot)
+#endif
+		{
 			Display    *dpy = DisplayOfScreen(screen);
 			Atom        __SWM_VROOT = None;
 			int         i;
