@@ -1,5 +1,5 @@
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)xlock.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
 
 #endif
 
@@ -171,7 +171,7 @@ static const char sccsid[] = "@(#)xlock.c	4.07 97/11/24 xlockmore";
 
 /*-
  * xscreensaver compatibility layer for xlockmore modules.
- * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@netscape.com>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -252,7 +252,7 @@ pre_merge_options(void)
 					new->value = "True";
 					new = &options[i++];
 					new->option = "-no-wireframe";
-					new->specifier = options[i - 1].specifier;
+					new->specifier = options[i - 2].specifier;
 					new->argKind = XrmoptionNoArg;
 					new->value = "False";
 				} else if (!strcmp(new->option, "-use3d")) {
@@ -261,7 +261,7 @@ pre_merge_options(void)
 					new->value = "True";
 					new = &options[i++];
 					new->option = "-no-3d";
-					new->specifier = options[i - 1].specifier;
+					new->specifier = options[i - 2].specifier;
 					new->argKind = XrmoptionNoArg;
 					new->value = "False";
 				} else if (!strcmp(new->option, "-mouse")) {
@@ -270,7 +270,7 @@ pre_merge_options(void)
 					new->value = "True";
 					new = &options[i++];
 					new->option = "-no-mouse";
-					new->specifier = options[i - 1].specifier;
+					new->specifier = options[i - 2].specifier;
 					new->argKind = XrmoptionNoArg;
 					new->value = "False";
 				} else if (!strcmp(new->option, "-fullrandom")) {
@@ -279,7 +279,7 @@ pre_merge_options(void)
 					new->value = "True";
 					new = &options[i++];
 					new->option = "-no-fullrandom";
-					new->specifier = options[i - 1].specifier;
+					new->specifier = options[i - 2].specifier;
 					new->argKind = XrmoptionNoArg;
 					new->value = "False";
 				} else if (!strcmp(new->option, "-verbose")) {
@@ -288,7 +288,7 @@ pre_merge_options(void)
 					new->value = "True";
 					new = &options[i++];
 					new->option = "-no-verbose";
-					new->specifier = options[i - 1].specifier;
+					new->specifier = options[i - 2].specifier;
 					new->argKind = XrmoptionNoArg;
 					new->value = "False";
 				} else {
@@ -470,7 +470,7 @@ xlockmore_screenhack(Display * dpy, Window window,
 
 	mi.pause = get_integer_resource("delay", "Usecs");
 
-	mi.batchcount = get_integer_resource("count", "Int");
+	mi.count = get_integer_resource("count", "Int");
 	mi.cycles = get_integer_resource("cycles", "Int");
 	mi.size = get_integer_resource("size", "Int");
 	mi.ncolors = get_integer_resource("ncolors", "Int");
@@ -554,7 +554,7 @@ xlockmore_screenhack(Display * dpy, Window window,
 		mi.pause = orig_pause;
 
 		if (hack_free) {
-			if (i++ > (mi.batchcount / 4) &&
+			if (i++ > (mi.count / 4) &&
 			    (start + 5) < (now = time((time_t) 0))) {
 				i = 0;
 				start = now;
@@ -1157,7 +1157,11 @@ mode_info(Display * display, int scrn, Window window, int iconic)
 		MI_SET_FLAG_STATE(mi, WI_FLAG_INWINDOW, inwindow);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_INROOT, inroot);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_NOLOCK, nolock);
-		MI_SET_FLAG_STATE(mi, WI_FLAG_INSTALL, install);
+#ifdef USE_DTSAVER
+		MI_SET_FLAG_STATE(mi, WI_FLAG_INSTALL, install && !inroot && !dtsaver);
+#else
+		MI_SET_FLAG_STATE(mi, WI_FLAG_INSTALL, install && !inroot);
+#endif
 		MI_SET_FLAG_STATE(mi, WI_FLAG_DEBUG, debug);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_USE3D, use3d &&
 			    !(mono || CellsOfScreen(MI_SCREENPTR(mi)) <= 2));
@@ -1918,47 +1922,6 @@ getPassword(void)
 	XSetForeground(dsp, Scr[screen].gc, Scr[screen].bg_pixel);
 	XFillRectangle(dsp, Scr[screen].window, Scr[screen].gc,
 		       0, 0, xgwa.width, xgwa.height);
-
-	if (mailCmd && mailCmd[0]) {
-#ifdef ORIGINAL_XPM_PATCH
-		XpmImage   *mbxpm;
-		mailboxInfo *mbi;
-		int         x, y;
-
-		if (system(mailCmd)) {
-			mbxpm = nomail_xpmimg;
-			mbi = &Scr[screen].mb.nomail;
-		} else {
-			mbxpm = mail_xpmimg;
-			mbi = &Scr[screen].mb.mail;
-		}
-		x = ((xgwa.width / 2) - (mbxpm->width / 2));
-		y = ((Scr[screen].planpos.y - 5) - mbxpm->height);
-
-		if (mbxpm) {
-			XCopyArea(dsp, mbi->pixmap,
-				  Scr[screen].window, Scr[screen].mb.mbgc,
-				  0, 0,
-				  mbxpm->width, mbxpm->height, x, y);
-		}
-#else
-		mailboxInfo *mbi;
-		int         x, y;
-
-		if (system(mailCmd)) {
-			mbi = &Scr[screen].mb.nomail;
-		} else {
-			mbi = &Scr[screen].mb.mail;
-		}
-		x = ((xgwa.width / 2) - (mbi->width / 2));
-		y = ((Scr[screen].planpos.y - 5) - mbi->height);
-		XSetTSOrigin(dsp, Scr[screen].mb.mbgc, x, y);
-		XSetStipple(dsp, Scr[screen].mb.mbgc, mbi->pixmap);
-		XSetFillStyle(dsp, Scr[screen].mb.mbgc, FillOpaqueStippled);
-		XFillRectangle(dsp, Scr[screen].window, Scr[screen].mb.mbgc,
-			       x, y, mbi->width, mbi->height);
-#endif
-	}
 	XMapWindow(dsp, Scr[screen].icon);
 	XRaiseWindow(dsp, Scr[screen].icon);
 
@@ -2080,6 +2043,47 @@ getPassword(void)
 	}
 	XFlush(dsp);
 
+	if (mailCmd && mailCmd[0]) {
+#ifdef ORIGINAL_XPM_PATCH
+		XpmImage   *mbxpm;
+		mailboxInfo *mbi;
+		int         x, y;
+
+		if (system(mailCmd)) {
+			mbxpm = nomail_xpmimg;
+			mbi = &Scr[screen].mb.nomail;
+		} else {
+			mbxpm = mail_xpmimg;
+			mbi = &Scr[screen].mb.mail;
+		}
+		x = (DisplayWidth(dsp, screen) - mbxpm->width) / 2;
+		y = (Scr[screen].planpos.y - 5) - mbxpm->height;
+
+		if (mbxpm) {
+			XCopyArea(dsp, mbi->pixmap,
+				  Scr[screen].window, Scr[screen].mb.mbgc,
+				  0, 0,
+				  mbxpm->width, mbxpm->height, x, y);
+		}
+#else
+		mailboxInfo *mbi;
+		int         x, y;
+
+		if (system(mailCmd)) {
+			mbi = &Scr[screen].mb.nomail;
+		} else {
+			mbi = &Scr[screen].mb.mail;
+		}
+		x = (DisplayWidth(dsp, screen) - mbi->width) / 2;
+		y = (Scr[screen].planpos.y - 5) - mbi->height;
+		XSetTSOrigin(dsp, Scr[screen].mb.mbgc, x, y);
+		XSetStipple(dsp, Scr[screen].mb.mbgc, mbi->pixmap);
+		XSetFillStyle(dsp, Scr[screen].mb.mbgc, FillOpaqueStippled);
+		XFillRectangle(dsp, Scr[screen].window, Scr[screen].mb.mbgc,
+			       x, y, mbi->width, mbi->height);
+#endif
+	}
+
 	done = False;
 	while (!done) {
 #ifdef USE_SOUND
@@ -2805,7 +2809,8 @@ main(int argc, char **argv)
 
 #ifdef FORCESINGLE
 	/* Safer to keep this after the calloc in case ScreenCount is used */
-	screens = 1;
+	startscreen = DefaultScreen(dsp);
+	screens = startscreen + 1;
 #endif
 
 #ifdef USE_DTSAVER
@@ -2839,26 +2844,22 @@ main(int argc, char **argv)
 			}
 			Scr[this_screen].window = saver_wins[this_win];
 		}
-#if 0
-		for (this_screen = screens - 1; this_screen >= 0; this_screen--) {
-			if (Scr[this_screen].window != None)
+		/* Reduce to the screens that have windows.  Avoid problems and */
+    /* assume that if one fails there is only one good window. */
+		for (this_screen = startscreen; this_screen < screens; this_screen++) {
+			if (Scr[this_screen].window == None) {
+				startscreen = DefaultScreen(dsp);
+				screens = startscreen + 1;
 				break;
-			screens--;
+			}
 		}
-#endif
-	}
+	} else
 #endif
 
-	if (
-#ifdef USE_DTSAVER
-		   dtsaver ||
-#endif
-		   inwindow) {
+	if (inwindow) {
 		/* Reduce to the last screen requested */
-		int         this_screen = DefaultScreen(dsp);
-
-		screens = this_screen + 1;
-		startscreen = this_screen;
+		startscreen = DefaultScreen(dsp);
+		screens = startscreen + 1;
 	}
 	for (screen = startscreen; screen < screens; screen++) {
 		Screen     *scr = ScreenOfDisplay(dsp, screen);
@@ -2885,9 +2886,82 @@ main(int argc, char **argv)
 
 		Scr[screen].root = (parentSet) ? parent : RootWindowOfScreen(scr);
 		defaultVisualInfo(dsp, screen);
-		Scr[screen].colormap = cmap = xswa.colormap =
-			XCreateColormap(dsp, Scr[screen].root, Scr[screen].visual, AllocNone);
 
+/*-
+ * Some window managers like fvwm and tvtwm do not like it when an application
+ * thinks it can install a full screen colormap (i.e xlock).  It promptly
+ * deinstalls the colormap and this might lead to white backgrounds if
+ * CopyFromParent is not used.
+ * But if CopyFromParent is used one can not change the visual
+ * and one may get White = Black on PseudoColor (see bug mode).
+ * There is another spot in xlock.c like this one...
+ * As far as I can tell, this problem exists only if your using MesaGL.
+ */
+#if (defined( USE_GL ) && (!defined( MESA ) || defined( REALGLX ))) || !defined( COMPLIANT_COLORMAP )
+    Scr[screen].colormap = cmap = xswa.colormap =
+      XCreateColormap(dsp, Scr[screen].root, Scr[screen].visual, AllocNone);
+#else
+    cmap = DefaultColormapOfScreen(scr);
+    Scr[screen].colormap = None;
+#endif
+
+		xswa.override_redirect = True;
+		xswa.background_pixel = Scr[screen].black_pixel;
+		xswa.border_pixel = Scr[screen].white_pixel;
+		xswa.event_mask = KeyPressMask | ButtonPressMask |
+			VisibilityChangeMask | ExposureMask | StructureNotifyMask;
+		if (mousemotion)
+			xswa.event_mask |= MotionNotify;
+
+#ifdef USE_VROOT
+		if (inroot) {
+			Scr[screen].window = Scr[screen].root;
+			XChangeWindowAttributes(dsp, Scr[screen].window, CWBackPixel, &xswa);
+			/* this gives us these events from the root window */
+			XSelectInput(dsp, Scr[screen].window,
+				     VisibilityChangeMask | ExposureMask);
+		} else
+#endif
+#ifdef USE_DTSAVER
+		if (!dtsaver)
+#endif
+		{
+#define WIDTH (inwindow? WidthOfScreen(scr)/2 : (debug? WidthOfScreen(scr) - 100 : WidthOfScreen(scr)))
+#define HEIGHT (inwindow? HeightOfScreen(scr)/2 : (debug? HeightOfScreen(scr) - 100 : HeightOfScreen(scr)))
+#if (defined( USE_GL ) && (!defined( MESA ) || defined( REALGLX ))) || !defined( COMPLIANT_COLORMAP )
+#define CWMASK (((debug||inwindow||inroot)? 0 : CWOverrideRedirect) | CWBackPixel | CWBorderPixel | CWEventMask | CWColormap)
+#else
+#define CWMASK (((debug||inwindow||inroot)? 0 : CWOverrideRedirect) | CWBackPixel | CWBorderPixel | CWEventMask)
+#endif
+
+#if (defined( USE_GL ) && (!defined( MESA ) || defined( REALGLX ))) || !defined( COMPLIANT_COLORMAP )
+#define XLOCKWIN_DEPTH (Scr[screen].depth)
+#define XLOCKWIN_VISUAL (Scr[screen].visual)
+#else
+#define XLOCKWIN_DEPTH CopyFromParent
+#define XLOCKWIN_VISUAL CopyFromParent
+#endif
+
+			if (fullscreen) {
+				Scr[screen].window = XCreateWindow(dsp, Scr[screen].root, 0, 0,
+								   (unsigned int) WIDTH, (unsigned int) HEIGHT, 0,
+				XLOCKWIN_DEPTH, InputOutput, XLOCKWIN_VISUAL,
+							      CWMASK, &xswa);
+			} else {
+				sizeconfiguremask = CWX | CWY | CWWidth | CWHeight;
+				Scr[screen].fullsizeconfigure.x = 0;
+				Scr[screen].fullsizeconfigure.y = 0;
+				Scr[screen].fullsizeconfigure.width = WIDTH;
+				Scr[screen].fullsizeconfigure.height = HEIGHT;
+				Scr[screen].window = XCreateWindow(dsp, Scr[screen].root,
+						   (int) minisizeconfigure.x,
+						   (int) minisizeconfigure.y,
+				      (unsigned int) minisizeconfigure.width,
+				     (unsigned int) minisizeconfigure.height,
+								   0, XLOCKWIN_DEPTH, InputOutput, XLOCKWIN_VISUAL,
+							      CWMASK, &xswa);
+			}
+		}
 		if (use3d) {
 			XColor      C;
 
@@ -2956,53 +3030,8 @@ main(int argc, char **argv)
 			}
 
 		}
-		xswa.override_redirect = True;
-		xswa.background_pixel = Scr[screen].black_pixel;
-		xswa.border_pixel = Scr[screen].white_pixel;
-		xswa.event_mask = KeyPressMask | ButtonPressMask |
-			VisibilityChangeMask | ExposureMask | StructureNotifyMask;
-		if (mousemotion)
-			xswa.event_mask |= MotionNotify;
-
-#ifdef USE_VROOT
-		if (inroot) {
-			Scr[screen].window = Scr[screen].root;
-			XChangeWindowAttributes(dsp, Scr[screen].window, CWBackPixel, &xswa);
-			/* this gives us these events from the root window */
-			XSelectInput(dsp, Scr[screen].window,
-				     VisibilityChangeMask | ExposureMask);
-		} else
-#endif
-#ifdef USE_DTSAVER
-		if (!dtsaver)
-#endif
-		{
-#define WIDTH (inwindow? WidthOfScreen(scr)/2 : (debug? WidthOfScreen(scr) - 100 : WidthOfScreen(scr)))
-#define HEIGHT (inwindow? HeightOfScreen(scr)/2 : (debug? HeightOfScreen(scr) - 100 : HeightOfScreen(scr)))
-#define CWMASK (((debug||inwindow||inroot)? 0 : CWOverrideRedirect) | CWBackPixel | CWBorderPixel | CWEventMask | CWColormap)
-#define XLOCKWIN_DEPTH (Scr[screen].depth)
-#define XLOCKWIN_VISUAL (Scr[screen].visual)
-
-			if (fullscreen) {
-				Scr[screen].window = XCreateWindow(dsp, Scr[screen].root, 0, 0,
-								   (unsigned int) WIDTH, (unsigned int) HEIGHT, 0,
-				XLOCKWIN_DEPTH, InputOutput, XLOCKWIN_VISUAL,
-							      CWMASK, &xswa);
-			} else {
-				sizeconfiguremask = CWX | CWY | CWWidth | CWHeight;
-				Scr[screen].fullsizeconfigure.x = 0;
-				Scr[screen].fullsizeconfigure.y = 0;
-				Scr[screen].fullsizeconfigure.width = WIDTH;
-				Scr[screen].fullsizeconfigure.height = HEIGHT;
-				Scr[screen].window = XCreateWindow(dsp, Scr[screen].root,
-						   (int) minisizeconfigure.x,
-						   (int) minisizeconfigure.y,
-				      (unsigned int) minisizeconfigure.width,
-				     (unsigned int) minisizeconfigure.height,
-								   0, XLOCKWIN_DEPTH, InputOutput, XLOCKWIN_VISUAL,
-							      CWMASK, &xswa);
-			}
-		}
+		fixColormap(dsp, Scr[screen].window, screen, ncolors, saturation,
+			    mono, install, inroot, inwindow, verbose);
 		if (debug || inwindow) {
 			XWMHints    xwmh;
 
@@ -3012,8 +3041,6 @@ main(int argc, char **argv)
 			       XA_WM_HINTS, XA_WM_HINTS, 32, PropModeReplace,
 					(unsigned char *) &xwmh, sizeof (xwmh) / sizeof (int));
 		}
-		fixColormap(dsp, Scr[screen].window, screen, ncolors, saturation,
-			    mono, install, inroot, inwindow, verbose);
 
 		if (debug) {
 			Scr[screen].iconpos.x = (DisplayWidth(dsp, screen) - 100 -
@@ -3055,7 +3082,11 @@ main(int argc, char **argv)
 		xswa.border_pixel = Scr[screen].white_pixel;
 		xswa.background_pixel = Scr[screen].black_pixel;
 		xswa.event_mask = ButtonPressMask;
+#if (defined( USE_GL ) && (!defined( MESA ) || defined( REALGLX ))) || !defined( COMPLIANT_COLORMAP )
 #define CIMASK CWBorderPixel | CWBackPixel | CWEventMask | CWColormap
+#else
+#define CIMASK CWBorderPixel | CWBackPixel | CWEventMask
+#endif
 		if (nolock)
 			Scr[screen].icon = None;
 		else {
